@@ -4,23 +4,13 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
-
 sub new { bless {index=>0}, shift }
 
 sub all {
 	my ($self, $cb) = @_;
 
-	my $docs = undef;
-	my $err  = undef;
-
-	if (defined $Test::Mock::Mango::error) {
-		$err                      = $Test::Mock::Mango::error;
-		$Test::Mock::Mango::error = undef;
-	}
-	else {
-		$docs = $Test::Mock::Mango::data->{collection};
-	}
+	my $err = ''; # TODO
+	my $docs = $Test::Mock::Mango::data->{collection};
 
 	return $cb->($self,$err,$docs) if $cb;
 	return $docs;
@@ -28,25 +18,12 @@ sub all {
 
 # ------------------------------------------------------------------------------
 
-# Naive no-op. Just return the parent so it can chain.
-sub limit { shift }
-
-# ------------------------------------------------------------------------------
-
 # Naive "next" - simply iterate through the docs in the defined test data
 sub next {
 	my ($self, $cb) = @_;
 
-	my $doc = undef;
-	my $err = undef;
-
-	if (defined $Test::Mock::Mango::error) {
-		$err                      = $Test::Mock::Mango::error;
-		$Test::Mock::Mango::error = undef;
-	}
-	else {
-		$doc = $Test::Mock::Mango::data->{collection}->[$self->{index}++];	
-	}
+	my $err = ''; # TODO
+	my $doc = $Test::Mock::Mango::data->{collection}->[$self->{index}++];
 
 	return $cb->($self,$err,$doc) if $cb;
 	return $doc;
@@ -57,16 +34,8 @@ sub next {
 sub count {
 	my ($self,$cb) = @_;
 
-	my $count = undef;
-	my $err   = undef;
-
-	if (defined $Test::Mock::Mango::error) {
-		$err                      = $Test::Mock::Mango::error;
-		$Test::Mock::Mango::error = undef;
-	}
-	else {
-		$count = scalar @{$Test::Mock::Mango::data->{collection}};
-	}
+	my $err = ''; # TODO
+	my $count = scalar @{$Test::Mock::Mango::data->{collection}};
 
 	return $cb->($self,$err,$count) if $cb;
 	return $count;
@@ -81,13 +50,13 @@ sub backlog {
 
 1;
 
-=encoding utf8
+__END__
 
-=head1 NAME
+=head1 Title
 
 Test::Mock::Mango::Cursor - fake Mango::Cursor
 
-=head1 DESCRIPTION
+=head1 Description
 
 Simulated mango cursor for unit testing as part of L<Test::Mock::Mango>.
 
